@@ -17,9 +17,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __TIFF_DOCUMENT_H__
-#define __TIFF_DOCUMENT_H__
+#pragma once
 
+#include "ev-macros.h"
 #include "ev-document.h"
 
 G_BEGIN_DECLS
@@ -31,8 +31,8 @@ G_BEGIN_DECLS
 typedef struct _TiffDocument TiffDocument;
 
 GType                 tiff_document_get_type  (void) G_GNUC_CONST;
-G_MODULE_EXPORT GType register_evince_backend (GTypeModule *module);
-     
-G_END_DECLS
 
-#endif /* __TIFF_DOCUMENT_H__ */
+EV_PUBLIC
+GType                 register_evince_backend (GTypeModule *module);
+
+G_END_DECLS
