@@ -47,7 +47,7 @@ const gchar *
 ev_link_get_title (EvLink *self)
 {
 	g_return_val_if_fail (EV_IS_LINK (self), NULL);
-	
+
 	return self->priv->title;
 }
 
@@ -61,7 +61,7 @@ EvLinkAction *
 ev_link_get_action (EvLink *self)
 {
 	g_return_val_if_fail (EV_IS_LINK (self), NULL);
-	
+
 	return self->priv->action;
 }
 
@@ -97,10 +97,10 @@ ev_link_set_property (GObject      *object,
 		      GParamSpec   *param_spec)
 {
 	EvLink *self = EV_LINK (object);
-	
+
 	switch (prop_id) {
 	        case PROP_TITLE:
-			self->priv->title = g_value_dup_string (value);	
+			self->priv->title = g_value_dup_string (value);
 			break;
 	        case PROP_ACTION:
 			self->priv->action = g_value_dup_object (value);
@@ -120,11 +120,7 @@ ev_link_finalize (GObject *object)
 
 	priv = EV_LINK (object)->priv;
 
-	if (priv->title) {
-		g_free (priv->title);
-		priv->title = NULL;
-	}
-
+	g_clear_pointer (&priv->title, g_free);
 	g_clear_object (&priv->action);
 
 	G_OBJECT_CLASS (ev_link_parent_class)->finalize (object);
@@ -180,5 +176,3 @@ ev_link_new (const char   *title,
 				      "action", action,
 				      NULL));
 }
-
-
