@@ -130,20 +130,9 @@ ev_job_dispose (GObject *object)
 
 	job = EV_JOB (object);
 
-	if (job->document) {
-		g_object_unref (job->document);
-		job->document = NULL;
-	}
-
-	if (job->cancellable) {
-		g_object_unref (job->cancellable);
-		job->cancellable = NULL;
-	}
-
-	if (job->error) {
-		g_error_free (job->error);
-		job->error = NULL;
-	}
+	g_clear_object (&job->document);
+	g_clear_object (&job->cancellable);
+	g_clear_error (&job->error);
 
 	(* G_OBJECT_CLASS (ev_job_parent_class)->dispose) (object);
 }
@@ -181,15 +170,15 @@ emit_finished (EvJob *job)
 	ev_debug_message (DEBUG_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
 
 	job->idle_finished_id = 0;
-	
+
 	if (job->cancelled) {
 		ev_debug_message (DEBUG_JOBS, "%s (%p) job was cancelled, do not emit finished", EV_GET_TYPE_NAME (job), job);
 	} else {
 		ev_profiler_stop (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
 		g_signal_emit (job, job_signals[FINISHED], 0);
 	}
-	
-	return FALSE;
+
+	return G_SOURCE_REMOVE;
 }
 
 static void
@@ -201,9 +190,9 @@ ev_job_emit_finished (EvJob *job)
 		ev_debug_message (DEBUG_JOBS, "%s (%p) job was cancelled, returning", EV_GET_TYPE_NAME (job), job);
 		return;
 	}
-	
+
 	job->finished = TRUE;
-	
+
 	if (job->run_mode == EV_JOB_RUN_THREAD) {
 		job->idle_finished_id =
 			g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
@@ -220,7 +209,7 @@ gboolean
 ev_job_run (EvJob *job)
 {
 	EvJobClass *class = EV_JOB_GET_CLASS (job);
-	
+
 	return class->run (job);
 }
 
@@ -232,7 +221,7 @@ ev_job_cancel (EvJob *job)
 
 	ev_debug_message (DEBUG_JOBS, "job %s (%p) cancelled", EV_GET_TYPE_NAME (job), job);
 	ev_profiler_stop (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
-	
+
 	/* This should never be called from a thread */
 	job->cancelled = TRUE;
 	g_cancellable_cancel (job->cancellable);
@@ -252,22 +241,22 @@ ev_job_failed (EvJob       *job,
 {
 	va_list args;
 	gchar  *message;
-	
+
 	if (job->failed || job->finished)
 		return;
 
 	ev_debug_message (DEBUG_JOBS, "job %s (%p) failed", EV_GET_TYPE_NAME (job), job);
-	
+
 	job->failed = TRUE;
-	
+
 	va_start (args, format);
 	message = g_strdup_vprintf (format, args);
 	va_end (args);
-	
+
 	job->error = g_error_new_literal (domain, code, message);
 	g_free (message);
-	
-	ev_job_emit_finished (job);                                                                                                               
+
+	ev_job_emit_finished (job);
 }
 
 /**
@@ -281,7 +270,7 @@ ev_job_failed_from_error (EvJob  *job,
 {
 	if (job->failed || job->finished)
 		return;
-	
+
 	ev_debug_message (DEBUG_JOBS, "job %s (%p) failed", EV_GET_TYPE_NAME (job), job);
 
 	job->failed = TRUE;
@@ -297,7 +286,7 @@ ev_job_succeeded (EvJob *job)
 		return;
 
 	ev_debug_message (DEBUG_JOBS, "job %s (%p) succeeded", EV_GET_TYPE_NAME (job), job);
-	
+
 	job->failed = FALSE;
 	ev_job_emit_finished (job);
 }
@@ -340,13 +329,10 @@ ev_job_links_dispose (GObject *object)
 	EvJobLinks *job;
 
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	job = EV_JOB_LINKS (object);
 
-	if (job->model) {
-		g_object_unref (job->model);
-		job->model = NULL;
-	}
+	g_clear_object (&job->model);
 
 	(* G_OBJECT_CLASS (ev_job_links_parent_class)->dispose) (object);
 }
@@ -390,7 +376,7 @@ ev_job_links_run (EvJob *job)
 
 	ev_debug_message (DEBUG_JOBS, NULL);
 	ev_profiler_start (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
-	
+
 	ev_document_doc_mutex_lock ();
 	job_links->model = ev_document_links_get_links_model (EV_DOCUMENT_LINKS (job->document));
 	ev_document_doc_mutex_unlock ();
@@ -398,7 +384,7 @@ ev_job_links_run (EvJob *job)
 	gtk_tree_model_foreach (job_links->model, (GtkTreeModelForeachFunc)fill_page_labels, job);
 
 	ev_job_succeeded (job);
-	
+
 	return FALSE;
 }
 
@@ -421,7 +407,7 @@ ev_job_links_new (EvDocument *document)
 
 	job = g_object_new (EV_TYPE_JOB_LINKS, NULL);
 	job->document = g_object_ref (document);
-	
+
 	return job;
 }
 
@@ -454,14 +440,10 @@ ev_job_attachments_dispose (GObject *object)
 	EvJobAttachments *job;
 
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	job = EV_JOB_ATTACHMENTS (object);
 
-	if (job->attachments) {
-		g_list_foreach (job->attachments, (GFunc)g_object_unref, NULL);
-		g_list_free (job->attachments);
-		job->attachments = NULL;
-	}
+	g_list_free_full (g_steal_pointer (&job->attachments), g_object_unref);
 
 	(* G_OBJECT_CLASS (ev_job_attachments_parent_class)->dispose) (object);
 }
@@ -503,7 +485,7 @@ ev_job_attachments_new (EvDocument *document)
 
 	job = g_object_new (EV_TYPE_JOB_ATTACHMENTS, NULL);
 	job->document = g_object_ref (document);
-	
+
 	return job;
 }
 
@@ -523,11 +505,7 @@ ev_job_annots_dispose (GObject *object)
 
 	job = EV_JOB_ANNOTS (object);
 
-	if (job->annots) {
-		g_list_foreach (job->annots, (GFunc)ev_mapping_list_unref, NULL);
-		g_list_free (job->annots);
-		job->annots = NULL;
-	}
+	g_list_free_full (g_steal_pointer (&job->annots), (GDestroyNotify) ev_mapping_list_unref);
 
 	G_OBJECT_CLASS (ev_job_annots_parent_class)->dispose (object);
 }
@@ -602,20 +580,9 @@ ev_job_render_dispose (GObject *object)
 
 	ev_debug_message (DEBUG_JOBS, "page: %d (%p)", job->page, job);
 
-	if (job->surface) {
-		cairo_surface_destroy (job->surface);
-		job->surface = NULL;
-	}
-
-	if (job->selection) {
-		cairo_surface_destroy (job->selection);
-		job->selection = NULL;
-	}
-
-	if (job->selection_region) {
-		cairo_region_destroy (job->selection_region);
-		job->selection_region = NULL;
-	}
+	g_clear_pointer (&job->surface, cairo_surface_destroy);
+	g_clear_pointer (&job->selection, cairo_surface_destroy);
+	g_clear_pointer (&job->selection_region, cairo_region_destroy);
 
 	(* G_OBJECT_CLASS (ev_job_render_parent_class)->dispose) (object);
 }
@@ -629,11 +596,11 @@ ev_job_render_run (EvJob *job)
 
 	ev_debug_message (DEBUG_JOBS, "page: %d (%p)", job_render->page, job);
 	ev_profiler_start (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
-	
+
 	ev_document_doc_mutex_lock ();
 
 	ev_profiler_start (EV_PROFILE_JOBS, "Rendering page %d", job_render->page);
-		
+
 	ev_document_fc_mutex_lock ();
 
 	ev_page = ev_document_get_page (job->document, job_render->page);
@@ -699,9 +666,9 @@ ev_job_render_run (EvJob *job)
 
 	ev_document_fc_mutex_unlock ();
 	ev_document_doc_mutex_unlock ();
-	
+
 	ev_job_succeeded (job);
-	
+
 	return FALSE;
 }
 
@@ -726,7 +693,7 @@ ev_job_render_new (EvDocument   *document,
 	EvJobRender *job;
 
 	ev_debug_message (DEBUG_JOBS, "page: %d", page);
-	
+
 	job = g_object_new (EV_TYPE_JOB_RENDER, NULL);
 
 	EV_JOB (job)->document = g_object_ref (document);
@@ -863,16 +830,9 @@ ev_job_thumbnail_dispose (GObject *object)
 	job = EV_JOB_THUMBNAIL (object);
 
 	ev_debug_message (DEBUG_JOBS, "%d (%p)", job->page, job);
-	
-	if (job->thumbnail) {
-		g_object_unref (job->thumbnail);
-		job->thumbnail = NULL;
-	}
 
-	if (job->thumbnail_surface) {
-		cairo_surface_destroy (job->thumbnail_surface);
-		job->thumbnail_surface = NULL;
-	}
+	g_clear_object (&job->thumbnail);
+	g_clear_pointer (&job->thumbnail_surface, cairo_surface_destroy);
 
 	(* G_OBJECT_CLASS (ev_job_thumbnail_parent_class)->dispose) (object);
 }
@@ -887,7 +847,7 @@ ev_job_thumbnail_run (EvJob *job)
 
 	ev_debug_message (DEBUG_JOBS, "%d (%p)", job_thumb->page, job);
 	ev_profiler_start (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
-	
+
 	ev_document_doc_mutex_lock ();
 
 	page = ev_document_get_page (job->document, job_thumb->page);
@@ -920,7 +880,7 @@ ev_job_thumbnail_run (EvJob *job)
 	} else {
 		ev_job_succeeded (job);
 	}
-	
+
 	return FALSE;
 }
 
@@ -943,7 +903,7 @@ ev_job_thumbnail_new (EvDocument *document,
 	EvJobThumbnail *job;
 
 	ev_debug_message (DEBUG_JOBS, "%d", page);
-	
+
 	job = g_object_new (EV_TYPE_JOB_THUMBNAIL, NULL);
 
 	EV_JOB (job)->document = g_object_ref (document);
@@ -1018,11 +978,11 @@ ev_job_fonts_run (EvJob *job)
 	EvDocumentFonts *fonts = EV_DOCUMENT_FONTS (job->document);
 
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	/* Do not block the main loop */
 	if (!ev_document_doc_mutex_trylock ())
 		return TRUE;
-	
+
 	if (!ev_document_fc_mutex_trylock ())
 		return TRUE;
 
@@ -1041,7 +1001,7 @@ ev_job_fonts_run (EvJob *job)
 
 	if (job_fonts->scan_completed)
 		ev_job_succeeded (job);
-	
+
 	return !job_fonts->scan_completed;
 }
 
@@ -1049,9 +1009,9 @@ static void
 ev_job_fonts_class_init (EvJobFontsClass *class)
 {
 	EvJobClass *job_class = EV_JOB_CLASS (class);
-	
+
 	job_class->run = ev_job_fonts_run;
-	
+
 	job_fonts_signals[FONTS_UPDATED] =
 		g_signal_new ("updated",
 			      EV_TYPE_JOB_FONTS,
@@ -1069,7 +1029,7 @@ ev_job_fonts_new (EvDocument *document)
 	EvJobFonts *job;
 
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	job = g_object_new (EV_TYPE_JOB_FONTS, NULL);
 
 	EV_JOB (job)->document = g_object_ref (document);
@@ -1090,16 +1050,9 @@ ev_job_load_dispose (GObject *object)
 	EvJobLoad *job = EV_JOB_LOAD (object);
 
 	ev_debug_message (DEBUG_JOBS, "%s", job->uri);
-	
-	if (job->uri) {
-		g_free (job->uri);
-		job->uri = NULL;
-	}
 
-	if (job->password) {
-		g_free (job->password);
-		job->password = NULL;
-	}
+	g_clear_pointer (&job->uri, g_free);
+	g_clear_pointer (&job->password, g_free);
 
 	(* G_OBJECT_CLASS (ev_job_load_parent_class)->dispose) (object);
 }
@@ -1109,10 +1062,10 @@ ev_job_load_run (EvJob *job)
 {
 	EvJobLoad *job_load = EV_JOB_LOAD (job);
 	GError    *error = NULL;
-	
+
 	ev_debug_message (DEBUG_JOBS, "%s", job_load->uri);
 	ev_profiler_start (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
-	
+
 	ev_document_fc_mutex_lock ();
 
 	/* This job may already have a document even if the job didn't complete
@@ -1125,7 +1078,7 @@ ev_job_load_run (EvJob *job)
 			ev_document_security_set_password (EV_DOCUMENT_SECURITY (job->document),
 							   job_load->password);
 		}
-		
+
 		job->failed = FALSE;
 		job->finished = FALSE;
 		g_clear_error (&job->error);
@@ -1168,7 +1121,7 @@ ev_job_load_new (const gchar *uri)
 	EvJobLoad *job;
 
 	ev_debug_message (DEBUG_JOBS, "%s", uri);
-	
+
 	job = g_object_new (EV_TYPE_JOB_LOAD, NULL);
 	job->uri = g_strdup (uri);
 
@@ -1179,7 +1132,7 @@ void
 ev_job_load_set_uri (EvJobLoad *job, const gchar *uri)
 {
 	ev_debug_message (DEBUG_JOBS, "%s", uri);
-	
+
 	if (job->uri)
 		g_free (job->uri);
 	job->uri = g_strdup (uri);
@@ -1219,15 +1172,10 @@ ev_job_load_stream_dispose (GObject *object)
         EvJobLoadStream *job = EV_JOB_LOAD_STREAM (object);
         EvJobLoadStreamPrivate *priv = ev_job_load_stream_get_instance_private (job);
 
-        if (job->stream) {
-                g_object_unref (job->stream);
-                job->stream = NULL;
-        }
+	g_clear_object (&job->stream);
 
-        g_free (priv->mime_type);
-        priv->mime_type = NULL;
-        g_free (job->password);
-        job->password = NULL;
+	g_clear_pointer (&priv->mime_type, g_free);
+	g_clear_pointer (&job->password, g_free);
 
         G_OBJECT_CLASS (ev_job_load_stream_parent_class)->dispose (object);
 }
@@ -1379,13 +1327,8 @@ ev_job_load_gfile_dispose (GObject *object)
 {
         EvJobLoadGFile *job = EV_JOB_LOAD_GFILE (object);
 
-        if (job->gfile) {
-                g_object_unref (job->gfile);
-                job->gfile = NULL;
-        }
-
-        g_free (job->password);
-        job->password = NULL;
+	g_clear_object (&job->gfile);
+	g_clear_pointer (&job->password, g_free);
 
         G_OBJECT_CLASS (ev_job_load_gfile_parent_class)->dispose (object);
 }
@@ -1544,10 +1487,8 @@ ev_job_load_fd_dispose (GObject *object)
                 job->fd = -1;
         }
 
-        g_free (job->mime_type);
-        job->mime_type = NULL;
-        g_free (job->password);
-        job->password = NULL;
+	g_clear_pointer (&job->mime_type, g_free);
+	g_clear_pointer (&job->password, g_free);
 
         G_OBJECT_CLASS (ev_job_load_fd_parent_class)->dispose (object);
 }
@@ -1787,16 +1728,9 @@ ev_job_save_dispose (GObject *object)
 	EvJobSave *job = EV_JOB_SAVE (object);
 
 	ev_debug_message (DEBUG_JOBS, "%s", job->uri);
-	
-	if (job->uri) {
-		g_free (job->uri);
-		job->uri = NULL;
-	}
 
-	if (job->document_uri) {
-		g_free (job->document_uri);
-		job->document_uri = NULL;
-	}
+	g_clear_pointer (&job->uri, g_free);
+	g_clear_pointer (&job->document_uri, g_free);
 
 	(* G_OBJECT_CLASS (ev_job_save_parent_class)->dispose) (object);
 }
@@ -1809,7 +1743,7 @@ ev_job_save_run (EvJob *job)
 	gchar     *tmp_filename = NULL;
 	gchar     *local_uri;
 	GError    *error = NULL;
-	
+
 	ev_debug_message (DEBUG_JOBS, "uri: %s, document_uri: %s", job_save->uri, job_save->document_uri);
 	ev_profiler_start (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
 
@@ -1836,7 +1770,7 @@ ev_job_save_run (EvJob *job)
 		g_free (local_uri);
 		ev_job_failed_from_error (job, error);
 		g_error_free (error);
-		
+
 		return FALSE;
 	}
 
@@ -1847,11 +1781,11 @@ ev_job_save_run (EvJob *job)
 		EvCompressionType ctype = EV_COMPRESSION_NONE;
 		const gchar      *ext;
 		gchar            *uri_comp;
-		
+
 		ext = g_strrstr (job_save->document_uri, ".gz");
 		if (ext && g_ascii_strcasecmp (ext, ".gz") == 0)
 			ctype = EV_COMPRESSION_GZIP;
-		
+
 		ext = g_strrstr (job_save->document_uri, ".bz2");
 		if (ext && g_ascii_strcasecmp (ext, ".bz2") == 0)
 			ctype = EV_COMPRESSION_BZIP2;
@@ -1873,7 +1807,7 @@ ev_job_save_run (EvJob *job)
 		g_free (local_uri);
 		ev_job_failed_from_error (job, error);
 		g_error_free (error);
-		
+
 		return FALSE;
 	}
 
@@ -1895,7 +1829,7 @@ ev_job_save_run (EvJob *job)
 	} else {
 		ev_job_succeeded (job);
 	}
-	
+
 	return FALSE;
 }
 
@@ -1941,10 +1875,7 @@ ev_job_find_dispose (GObject *object)
 
 	ev_debug_message (DEBUG_JOBS, NULL);
 
-	if (job->text) {
-		g_free (job->text);
-		job->text = NULL;
-	}
+	g_clear_pointer (&job->text, g_free);
 
 	if (job->pages) {
 		gint i;
@@ -1953,10 +1884,9 @@ ev_job_find_dispose (GObject *object)
 			g_list_free_full (job->pages[i], (GDestroyNotify)ev_find_rectangle_free);
 		}
 
-		g_free (job->pages);
-		job->pages = NULL;
+		g_clear_pointer (&job->pages, g_free);
 	}
-	
+
 	(* G_OBJECT_CLASS (ev_job_find_parent_class)->dispose) (object);
 }
 
@@ -1969,11 +1899,11 @@ ev_job_find_run (EvJob *job)
 	GList          *matches;
 
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	/* Do not block the main loop */
 	if (!ev_document_doc_mutex_trylock ())
 		return TRUE;
-	
+
 #ifdef EV_ENABLE_DEBUG
 	/* We use the #ifdef in this case because of the if */
 	if (job_find->current_page == job_find->start_page)
@@ -1984,7 +1914,7 @@ ev_job_find_run (EvJob *job)
 	matches = ev_document_find_find_text_extended (find, ev_page, job_find->text,
                                                        job_find->options);
 	g_object_unref (ev_page);
-	
+
 	ev_document_doc_mutex_unlock ();
 
 	if (!job_find->has_results)
@@ -1992,7 +1922,7 @@ ev_job_find_run (EvJob *job)
 
 	job_find->pages[job_find->current_page] = matches;
 	g_signal_emit (job_find, job_find_signals[FIND_UPDATED], 0, job_find->current_page);
-		       
+
 	job_find->current_page = (job_find->current_page + 1) % job_find->n_pages;
 	if (job_find->current_page == job_find->start_page) {
 		ev_job_succeeded (job);
@@ -2008,10 +1938,10 @@ ev_job_find_class_init (EvJobFindClass *class)
 {
 	EvJobClass   *job_class = EV_JOB_CLASS (class);
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-	
+
 	job_class->run = ev_job_find_run;
 	gobject_class->dispose = ev_job_find_dispose;
-	
+
 	job_find_signals[FIND_UPDATED] =
 		g_signal_new ("updated",
 			      EV_TYPE_JOB_FIND,
@@ -2031,9 +1961,9 @@ ev_job_find_new (EvDocument  *document,
 		 gboolean     case_sensitive)
 {
 	EvJobFind *job;
-	
+
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	job = g_object_new (EV_TYPE_JOB_FIND, NULL);
 
 	EV_JOB (job)->document = g_object_ref (document);
@@ -2120,7 +2050,7 @@ ev_job_find_get_progress (EvJobFind *job)
 
 	if (ev_job_is_finished (EV_JOB (job)))
 		return 1.0;
-	
+
 	if (job->current_page > job->start_page) {
 		pages_done = job->current_page - job->start_page + 1;
 	} else if (job->current_page == job->start_page) {
@@ -2163,13 +2093,10 @@ ev_job_layers_dispose (GObject *object)
 	EvJobLayers *job;
 
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	job = EV_JOB_LAYERS (object);
 
-	if (job->model) {
-		g_object_unref (job->model);
-		job->model = NULL;
-	}
+	g_clear_object (&job->model);
 
 	(* G_OBJECT_CLASS (ev_job_layers_parent_class)->dispose) (object);
 }
@@ -2181,13 +2108,13 @@ ev_job_layers_run (EvJob *job)
 
 	ev_debug_message (DEBUG_JOBS, NULL);
 	ev_profiler_start (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
-	
+
 	ev_document_doc_mutex_lock ();
 	job_layers->model = ev_document_layers_get_layers (EV_DOCUMENT_LAYERS (job->document));
 	ev_document_doc_mutex_unlock ();
-	
+
 	ev_job_succeeded (job);
-	
+
 	return FALSE;
 }
 
@@ -2210,7 +2137,7 @@ ev_job_layers_new (EvDocument *document)
 
 	job = g_object_new (EV_TYPE_JOB_LAYERS, NULL);
 	job->document = g_object_ref (document);
-	
+
 	return job;
 }
 
@@ -2228,13 +2155,10 @@ ev_job_export_dispose (GObject *object)
 	EvJobExport *job;
 
 	ev_debug_message (DEBUG_JOBS, NULL);
-	
+
 	job = EV_JOB_EXPORT (object);
 
-	if (job->rc) {
-		g_object_unref (job->rc);
-		job->rc = NULL;
-	}
+	g_clear_object (&job->rc);
 
 	(* G_OBJECT_CLASS (ev_job_export_parent_class)->dispose) (object);
 }
@@ -2249,27 +2173,27 @@ ev_job_export_run (EvJob *job)
 
 	ev_debug_message (DEBUG_JOBS, NULL);
 	ev_profiler_start (EV_PROFILE_JOBS, "%s (%p)", EV_GET_TYPE_NAME (job), job);
-	
+
 	ev_document_doc_mutex_lock ();
-	
+
 	ev_page = ev_document_get_page (job->document, job_export->page);
 	if (job_export->rc) {
 		job->failed = FALSE;
 		job->finished = FALSE;
 		g_clear_error (&job->error);
-		
+
 		ev_render_context_set_page (job_export->rc, ev_page);
 	} else {
 		job_export->rc = ev_render_context_new (ev_page, 0, 1.0);
 	}
 	g_object_unref (ev_page);
-	
+
 	ev_file_exporter_do_page (EV_FILE_EXPORTER (job->document), job_export->rc);
-	
+
 	ev_document_doc_mutex_unlock ();
-	
+
 	ev_job_succeeded (job);
-	
+
 	return FALSE;
 }
 
@@ -2292,7 +2216,7 @@ ev_job_export_new (EvDocument *document)
 
 	job = g_object_new (EV_TYPE_JOB_EXPORT, NULL);
 	job->document = g_object_ref (document);
-	
+
 	return job;
 }
 
@@ -2320,10 +2244,7 @@ ev_job_print_dispose (GObject *object)
 
 	job = EV_JOB_PRINT (object);
 
-	if (job->cr) {
-		cairo_destroy (job->cr);
-		job->cr = NULL;
-	}
+	g_clear_pointer (&job->cr, cairo_destroy);
 
 	(* G_OBJECT_CLASS (ev_job_print_parent_class)->dispose) (object);
 }
